@@ -1,6 +1,6 @@
 /*
     DrMIPS - Educational MIPS simulator
-    Copyright (C) 2013-2014 Bruno Nova <ei08109@fe.up.pt>
+    Copyright (C) 2013-2015 Bruno Nova <brunomb.nova@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 package org.feup.brunonova.drmips.gui;
 
 import java.awt.Color;
+import java.awt.Font;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Set;
@@ -77,12 +78,11 @@ public class CodeEditor extends TextEditorPane {
 	 */
 	public CodeEditor() {
 		super();
-		
 		scrollPane = new RTextScrollPane(this);
 		scrollPane.setIconRowHeaderEnabled(true);
-		
 		setRows(20);
 		setColumns(80);
+		setMarginLinePosition(80);
 		setAntiAliasingEnabled(true);
 		//setMarkOccurrences(true);
 		setLineWrap(true);
@@ -205,7 +205,7 @@ public class CodeEditor extends TextEditorPane {
 		String usage = instruction.getUsage();
 		desc += "<dt><b>" + Lang.t("usage") + ":</b></dt>";
 		desc += "<dd><pre>" + instruction.getUsage() + "</pre></dd>";
-		
+
 		// Arguments
 		if(instruction.hasArguments()) {
 			desc += "<dt><br /><b>" + Lang.t("arguments") + ":</b></dt>";
@@ -294,13 +294,12 @@ public class CodeEditor extends TextEditorPane {
 			summ += "<dt><br /><b>" + Lang.t("description") + ":</b></dt><dd>" + Lang.t("data_directive_description") +"</dd></dl>";
 			completeProvider.addCompletion(new BasicCompletion(completeProvider, ".data", desc, summ));
 
-			desc = Lang.t("data_directive");
-			summ = "<b><u><tt>.word </tt> (" + Lang.t("data_directive") + ")</u></b><br /><br /><dl>";
+			summ = "<b><u><tt>.word </tt> (" + Lang.t("directive") + ")</u></b><br /><br /><dl>";
 			summ += "<dt><b>" + Lang.t("usage") + ":</b></dt><dd><pre>.word 20, -13, 56, ...</pre></dd>";
 			summ += "<dt><br /><b>" + Lang.t("description") + ":</b></dt><dd>" + Lang.t("word_directive_description") +"</dd></dl>";
 			completeProvider.addCompletion(new BasicCompletion(completeProvider, ".word", desc, summ));
 
-			summ = "<b><u><tt>.space </tt> (" + Lang.t("data_directive") + ")</u></b><br /><br /><dl>";
+			summ = "<b><u><tt>.space </tt> (" + Lang.t("directive") + ")</u></b><br /><br /><dl>";
 			summ += "<dt><b>" + Lang.t("usage") + ":</b></dt><dd><pre>.space 16</pre></dd>";
 			summ += "<dt><br /><b>" + Lang.t("description") + ":</b></dt><dd>" + Lang.t("space_directive_description") +"</dd></dl>";
 			completeProvider.addCompletion(new BasicCompletion(completeProvider, ".space", desc, summ));
@@ -319,22 +318,40 @@ public class CodeEditor extends TextEditorPane {
 		setCaretColor(dark ? Color.WHITE : Color.BLACK);
 		setCurrentLineHighlightColor(dark ? (new Color(32, 32, 32)) : (new Color(255, 255, 170)));
 		setSelectionColor(dark ? (new Color(64, 64, 64)) : (new Color(200, 200, 255)));
-		
-		Style reservedWord = scheme.getStyle(Token.RESERVED_WORD);
-		Style preprocessor = scheme.getStyle(Token.PREPROCESSOR);
-		Style comment = scheme.getStyle(Token.COMMENT_EOL);
-		Style function = scheme.getStyle(Token.FUNCTION);
-		
-		scheme.setStyle(Token.IDENTIFIER, new Style(dark ? Color.WHITE : Color.BLACK));
-		scheme.setStyle(Token.RESERVED_WORD, new Style(dark ? (new Color(128, 128, 255)) : (new Color(0, 0, 255)), null, reservedWord.font));
-		scheme.setStyle(Token.RESERVED_WORD_2, new Style(dark ? (new Color(255, 128, 255)) : (new Color(128, 0, 255)), null, reservedWord.font));
-		scheme.setStyle(Token.LITERAL_NUMBER_DECIMAL_INT, new Style(dark ? (new Color(150, 70, 255)) : (new Color(100, 0, 200))));
-		scheme.setStyle(Token.OPERATOR, new Style(dark ? (new Color(255, 128, 128)) : (new Color(128, 64, 64))));
-		scheme.setStyle(Token.PREPROCESSOR, new Style(preprocessor.foreground, null, reservedWord.font));
-		scheme.setStyle(Token.ERROR_CHAR, new Style(Color.RED));
-		scheme.setStyle(Token.ERROR_IDENTIFIER, new Style(Color.RED));
-		scheme.setStyle(Token.ERROR_NUMBER_FORMAT, new Style(Color.RED));
-		scheme.setStyle(Token.FUNCTION, new Style(function.foreground, null, comment.font));
+		setMarginLineColor(dark ? Color.DARK_GRAY : Color.LIGHT_GRAY);
+
+		Font keywordFont = new Font(getDefaultFont().getFamily(), Font.BOLD, getDefaultFont().getSize());
+		Font commentFont = new Font(getDefaultFont().getFamily(), Font.ITALIC, getDefaultFont().getSize());
+		Style identifierStyle = new Style(dark ? Color.WHITE : Color.BLACK);
+		Style directiveStyle = new Style(dark ? new Color(0, 160, 160) : new Color(0, 128, 128), null, keywordFont);
+		Style errorStyle = new Style(Color.RED);
+
+		scheme.setStyle(Token.IDENTIFIER /* references to labels */,
+		                identifierStyle);
+		scheme.setStyle(Token.RESERVED_WORD /* instructions */,
+		                new Style(dark ? new Color(128, 128, 255) : new Color(0, 0, 255), null, keywordFont));
+		scheme.setStyle(Token.RESERVED_WORD_2 /* pseudo-instructions */,
+		                new Style(dark ? new Color(255, 128, 255) : new Color(128, 0, 255), null, keywordFont));
+		scheme.setStyle(Token.LITERAL_NUMBER_DECIMAL_INT /* integer numeric values */,
+		                identifierStyle);
+		scheme.setStyle(Token.OPERATOR /* argument separators (commas and parentheses) */,
+		                identifierStyle);
+		scheme.setStyle(Token.PREPROCESSOR /* .text and .data directives */,
+		                directiveStyle);
+		scheme.setStyle(Token.DATA_TYPE /* .word and .space directives */,
+		                directiveStyle);
+		scheme.setStyle(Token.ERROR_CHAR /* invalid characters (like special characters) */,
+		                errorStyle);
+		scheme.setStyle(Token.ERROR_IDENTIFIER /* invalid directives */,
+		                errorStyle);
+		scheme.setStyle(Token.ERROR_NUMBER_FORMAT /* invalid integer numeric values */,
+		                errorStyle);
+		scheme.setStyle(Token.FUNCTION /* labels */,
+		                new Style(dark ? new Color(160, 160, 160) : new Color(96, 96, 96), null, commentFont));
+		scheme.setStyle(Token.COMMENT_EOL /* comments */,
+		                new Style(dark ? new Color(0, 160, 0) : new Color(0, 128, 0), null, commentFont));
+		scheme.setStyle(Token.VARIABLE /* registers */,
+		                new Style(dark ? new Color(255, 128, 0) : new Color(192, 96, 0), null, keywordFont));
 	}
 	
 	
