@@ -1,6 +1,6 @@
 /*
     DrMIPS - Educational MIPS simulator
-    Copyright (C) 2013-2014 Bruno Nova <ei08109@fe.up.pt>
+    Copyright (C) 2013-2015 Bruno Nova <brunomb.nova@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -448,7 +448,7 @@ public class CPU {
 		
 		if(!maxIns.isEmpty()) {
 			for(Input in: maxIns) {
-				in.getConnectedOutput().setInCriticalPath();
+				in.getConnectedOutput().setInCriticalPath(true);
 				determineCriticalPath(in.getConnectedOutput().getComponent());
 			}
 		}
@@ -463,7 +463,7 @@ public class CPU {
 		for(Input i: component.getInputs()) {
 			if(i.canChangeComponentAccumulatedLatency() && i.getAccumulatedLatency() == lat 
 				&& i.isConnected() && !i.getConnectedOutput().isInCriticalPath()) {
-				i.getConnectedOutput().setInCriticalPath();
+				i.getConnectedOutput().setInCriticalPath(true);
 				determineCriticalPath(i.getConnectedOutput().getComponent());
 			}
 		}
