@@ -1,6 +1,6 @@
 /*
     DrMIPS - Educational MIPS simulator
-    Copyright (C) 2013-2014 Bruno Nova <ei08109@fe.up.pt>
+    Copyright (C) 2013-2015 Bruno Nova <brunomb.nova@gmail.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -343,7 +343,7 @@ public abstract class Component {
 		for(Input i: getInputs())
 			i.resetAccumulatedLatency();
 		for(Output o: getOutputs())
-			o.unsetInCriticalPath();
+			o.setInCriticalPath(false);
 	}
 	
 	/**
